<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="料盘码" prop="rackCode">
        <el-input
          v-model="queryParams.rackCode"
          placeholder="请输入料盘码"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="物料代码" prop="materialCode">
        <el-input
          v-model="queryParams.materialCode"
          placeholder="请输入物料代码"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="名称" prop="materialName">
        <el-input
          v-model="queryParams.materialName"
          placeholder="请输入名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
		     :loading="exportLoading"
          @click="handleExport"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="relationList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="料盘码" align="center" prop="rackCode" />
      <el-table-column label="物料代码" align="center" prop="materialCode" />
      <el-table-column label="名称" align="center" prop="materialName" />
      <el-table-column label="规格型号" align="center" prop="materialSpecifications" />
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改料架和物料维护对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="料盘码" prop="rackCode">
          <el-input v-model="form.rackCode" placeholder="请输入料盘码" />
        </el-form-item>
        <el-form-item label="物料代码" prop="materialCode">
          <el-autocomplete
            style="width: 100%"
            v-model="form.materialCode"
            :fetch-suggestions="querySearchAsync"
            placeholder="请输入内容"
            @select="handleSelect"
          ></el-autocomplete>
        </el-form-item>
        <el-form-item label="名称" prop="materialName">
          <el-input v-model="form.materialName" placeholder="请输入名称" />
        </el-form-item>
        <el-form-item label="规格型号" prop="materialSpecifications">
          <el-input v-model="form.materialSpecifications" placeholder="请输入规格型号" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { relationListInfo, listRelation, getRelation, delRelation, addRelation, updateRelation, exportRelation } from "@/api/shelf/relation";

export default {
  name: "Relation",
  components: {
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 料架和物料维护表格数据
      relationList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        rackCode: null,
        materialCode: null,
        materialName: null,
        materialSpecifications: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        rackCode: [
          { required: true, message: "料盘码不能为空", trigger: "blur" }
        ],
        materialCode: [
          { required: true, message: "物料代码不能为空", trigger: "change" }
        ],
        materialName: [
          { required: true, message: "名称不能为空", trigger: "blur" }
        ],
        materialSpecifications: [
          { required: true, message: "规格型号不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询料架和物料维护列表 */
    getList() {
      this.loading = true;
      listRelation(this.queryParams).then(response => {
        this.relationList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        relationId: null,
        rackCode: null,
        materialCode: null,
        materialName: null,
        materialSpecifications: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.relationId)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加料架和物料维护";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const relationId = row.relationId || this.ids
      getRelation(relationId).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改料架和物料维护";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.relationId != null) {
            updateRelation(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addRelation(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const relationIds = row.relationId || this.ids;
      this.$confirm('是否确认删除料架和物料维护编号为"' + relationIds + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delRelation(relationIds);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有料架和物料维护数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportRelation(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    },
    querySearchAsync(queryString, cb){
      relationListInfo({materialCode: queryString}).then(res => {
        const result = this.removeDuplicates(res.data,"materialCode");
        cb(result)
      });
    },
    // 最终推荐方案（根据单个属性去重）
     removeDuplicates(arr, prop) {
      const seen = new Set();
      return arr.filter(item => {
        if (seen.has(item[prop])) return false;
        item.value = item.materialCode;
        seen.add(item[prop]);
        return true;
      });
    },
    handleSelect(item){
      this.form.materialName = item.materialName;
      this.form.materialSpecifications = item.materialSpecifications;
    }
  }
};
</script>
